<?php
/**
 * Hotelica Theme Customizer
 *
 * @package Hotelica
 */

/**
 * Enqueue style for custom customize control.
 */
add_action( 'customize_controls_enqueue_scripts', 'blog_way_custom_customize_enqueue' );
function blog_way_custom_customize_enqueue() {

	wp_enqueue_style( 'blog-way-customize-controls', get_template_directory_uri() . '/inc/sections/customizer.css' );
}


add_action( 'customize_register', 'hotelica_upgrade_to_pro_msg' );
function hotelica_upgrade_to_pro_msg( $wp_customize ){

	// Load Upgrade to Pro control.
	require_once trailingslashit( get_template_directory() ) . '/inc/sections/controls.php';

	// Register custom section types.
	$wp_customize->register_section_type( 'Hotelica_Customize_section' );

	// Register sections.
	$wp_customize->add_section(
		new Hotelica_Customize_section(
			$wp_customize,
			'theme_upsell',
			array(
				'priority' => 1,
			)
		)
	);

}

if ( !class_exists( 'Kirki' ) ) {
	return;
}

add_action( 'init' , 'hotelica_get_kirki_fields' );

function hotelica_get_kirki_fields(){

	Kirki::add_config( 'my_theme', 
		array(
			'capability'    => 'edit_theme_options',
			'option_type'   => 'theme_mod',
		)
	);

	Kirki::add_panel( 'theme_options', array(
	    'title'       => esc_html__( 'Theme Options', 'hotelica' ),

	) );

	Kirki::add_section( 'theme_settings' ,
		array(
		    'title'          => esc_html__( 'Theme Settings' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'panel'          => 'theme_options',
		    'priority'       => 1,
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'theme_currency',
		'label'    => esc_html__( 'Currency', 'hotelica' ),
		'section'  => 'theme_settings',
		'default'  => esc_html__( 'USD', 'hotelica' ),
		'priority' => 1
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'sidebar_position',
		'label'       => esc_html__( 'Sidebar Position', 'hotelica' ),
		'section'     => 'theme_settings',
		'default'     => 'right',
		'priority'    => 1,
		'choices'     => array(
			'left'   => esc_html__( 'Left Sidebar', 'hotelica' ),
			'right' => esc_html__( 'Right Sidebar', 'hotelica' ),
		),
	) );

	Kirki::add_section( 'homepage_settings' ,
		array(
		    'title'          => esc_html__( 'Homepage Settings' , 'hotelica' ),
		    'priority'       => 1,
		    'capability'     => 'edit_theme_options',
		    'panel'          => 'theme_options',
		) 
	);

	Kirki::add_section( 'header_settings' ,
		array(
		    'title'          => esc_html__( 'Banner / Slider' , 'hotelica' ),
		    'priority'       => 1,
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'option_banner_slider',
		'label'       => esc_html__( 'Banner / Slider', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 'banner',
		'choices'     => array(
			'banner'   => esc_html__( 'Banner', 'hotelica' ),
			'slider' => esc_html__( 'Slider', 'hotelica' ),
		),
		'priority' => 1,
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'select',
		'settings'    => 'slider_category',
		'label'       => esc_html__( 'Select Slider Category', 'hotelica' ),
		'section'     => 'header_settings',
		'multiple'    => 1,
		'choices'     => Kirki_Helper::get_terms( array('taxonomy' => 'category') ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'text',
		'settings'    => 'slider_animation_speed',
		'label'       => esc_html__( 'Animation Speed', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 600,
		'description' => esc_html__( 'Set the speed of animations, in milliseconds', 'hotelica' ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'text',
		'settings'    => 'slider_slideshow_speed',
		'label'       => esc_html__( 'Slide Show Speed', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 7000,
		'description' => esc_html__( 'Set the speed of the slideshow cycling, in milliseconds.', 'hotelica' ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'slider_mousewheel',
		'label'       => esc_html__( 'Mousewheel', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 'disable',
		'choices'     => array(
			'enable'   => esc_html__( 'Enable', 'hotelica' ),
			'disable' => esc_html__( 'Disable', 'hotelica' ),
		),
		'description' => esc_html__( 'Allows slider navigating via mousewheel', 'hotelica' ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'keyboard_navigation',
		'label'       => esc_html__( 'Keyboard Navigation', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 'disable',
		'choices'     => array(
			'enable'   => esc_html__( 'Enable', 'hotelica' ),
			'disable' => esc_html__( 'Disable', 'hotelica' ),
		),
		'description' => esc_html__( 'Allow keyboard navigation to affect multiple sliders.', 'hotelica' ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'slider_randomize',
		'label'       => esc_html__( 'Randomize', 'hotelica' ),
		'section'     => 'header_settings',
		'default'     => 'disable',
		'choices'     => array(
			'enable'   => esc_html__( 'Enable', 'hotelica' ),
			'disable' => esc_html__( 'Disable', 'hotelica' ),
		),
		'description' => esc_html__( 'Randomize slide order, on load.', 'hotelica' ),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'slider',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'image',
		'settings'    => 'banner_image',
		'label'       => esc_html__( 'Banner Image', 'hotelica' ),
		'section'     => 'header_settings',
		'priority' => 2,
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'banner',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'banner_title',
		'label'    => esc_html__( 'Banner Title', 'hotelica' ),
		'section'  => 'header_settings',
		'default'  => esc_attr__( 'Welcome to hotelica', 'hotelica' ),
		'priority' => 4,
		'partial_refresh' => array(
		    'banner_title' => array(
		        'selector'        => '.banner_title_text',
		        'render_callback' => 'hotelica_get_banner_title',
		    ),
		),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'banner',
			),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'banner_subtitle',
		'label'    => esc_html__( 'Banner Sub Title', 'hotelica' ),
		'section'  => 'header_settings',
		'priority' => 5,
		'transport' => 'postMessage',
		'default' => esc_html__( 'Book Direct for Exclusive Offers and Lowest Rates Every Day From Our Official Website' , 'hotelica' ),
		'partial_refresh' => array(
		    'banner_subtitle' => array(
		        'selector'        => '.banner_subtitle_text',
		        'render_callback' => 'hotelica_get_banner_subtitle',
		    ),
		),
		'active_callback'    => array(
			array(
				'setting'  => 'option_banner_slider',
				'operator' => '==',
				'value'    => 'banner',
			),
		),
	) );

	/**
	* About US section
	*/

	Kirki::add_section( 'about_us_settings' ,
		array(
		    'title'          => esc_html__( 'About Us' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		   // 'panel'          => 'theme_options',
		    'section'          => 'homepage_settings',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'about_us_status',
		'label'       => esc_html__( 'Disable About Us Section', 'hotelica' ),
		'section'     => 'about_us_settings',
	) );

	/**
	* @since version 1.7
	*/

	Kirki::add_field( 'my_theme', array(
		'type'        => 'select',
		'settings'    => 'about_us_page',
		'label'       => esc_html__( 'Select about us page', 'hotelica' ),
		'section'     => 'about_us_settings',
		'multiple'    => 1,
		'choices'     => Kirki_Helper::get_posts( array( 'posts_per_page' => -1, 'post_type' => 'page' ) ),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'about_us_subtitle',
		'label'    => esc_html__( 'SubTitle', 'hotelica' ),
		'section'  => 'about_us_settings',
		'default'  => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'hotelica' ),
		'partial_refresh' => array(
		    'about_us_subtitle' => array(
		        'selector'        => '.about_us_section p',
		        'render_callback' => 'hotelica_get_aboutus_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'repeater',
		'label'       => esc_html__( 'Services', 'hotelica' ),
		'section'     => 'about_us_settings',
		'row_label' => array(
			'type' => 'text',
			'value' => esc_html__('Services', 'hotelica' ),
		),
		'settings'    => 'services_settings',
		'fields' => array(
			'title' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Title', 'hotelica' ),
				'default'     => esc_html__( 'Hotel Rooms', 'hotelica' ),
			),
			'number' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Numbers', 'hotelica' ),
				'default'     => 50,
			),
			'icon' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Fontawesome Icon', 'hotelica' ),
				'description' => esc_html__( 'eg. fa-cutlery', 'hotelica' ),
			)
		),
		'choices' => array(
		    'limit' => 4
		),
		'transport' => 'refresh',
	) );

	/**
	* Room listing section
	*/

	Kirki::add_section( 'room_listings_settings' ,
		array(
		    'title'          => esc_html__( 'Room Listings' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    //'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'room_listings_status',
		'label'       => esc_html__( 'Disable Room Listings Section', 'hotelica' ),
		'section'     => 'room_listings_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'room_listings_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'room_listings_settings',
		'default'  => esc_html__( 'Our Hotel Room Style', 'hotelica' ),
		'partial_refresh' => array(
		    'room_listings_title' => array(
		        'selector'        => '.room_listing h2',
		        'render_callback' => 'hotelica_get_room_listing_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'room_listing_subtitle',
		'label'    => esc_html__( 'SubTitle', 'hotelica' ),
		'section'  => 'room_listings_settings',
		'default'  => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'hotelica' ),
		'partial_refresh' => array(
		    'room_listing_subtitle' => array(
		        'selector'        => '.room_listing p',
		        'render_callback' => 'hotelica_get_room_listing_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'select',
		'settings' => 'room_listing_category',
		'label'    => esc_html__( 'Choose Room Category', 'hotelica' ),
		'section'  => 'room_listings_settings',
		'multiple'    => 1,
		'choices'     => hotelica_get_post_categories(),
	) );

	/**
	* Special Offer Section
	*/

	Kirki::add_section( 'special_offer_settings' ,
		array(
		    'title'          => esc_html__( 'Special Offer' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    //'panel'          => 'theme_options',
		    'section'          => 'homepage_settings',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'special_offer_status',
		'label'       => esc_html__( 'Disable Special Offer Section', 'hotelica' ),
		'section'     => 'special_offer_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'image',
		'settings'    => 'special_offer_banner',
		'label'       => esc_html__( 'Background Image', 'hotelica' ),
		'section'     => 'special_offer_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'select',
		'settings'    => 'special_offer_page',
		'label'       => esc_html__( 'Select Special Offer Page', 'hotelica' ),
		'section'     => 'special_offer_settings',
		'default'     => '',
		'multiple'    => 1,
		'choices'     => Kirki_Helper::get_posts( array( 'posts_per_page' => -1, 'post_type' => 'page' ) ),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'special_package_btn',
		'label'    => esc_html__( 'Button Text', 'hotelica' ),
		'section'  => 'special_offer_settings',
		'default'  => esc_html__( 'Grab Now', 'hotelica' ),
		'partial_refresh' => array(
		    'special_package_btn' => array(
		        'selector'        => '.special_package_btn',
		        'render_callback' => 'hotelica_special_package_btn_text',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'special_package_discount',
		'label'    => esc_html__( 'Discount Text', 'hotelica' ),
		'section'  => 'special_offer_settings',
		'default'  => esc_html__( '35% | off', 'hotelica' ),
		'partial_refresh' => array(
		    'special_package_discount' => array(
		        'selector'        => '.special_package_discount',
		        'render_callback' => 'hotelica_get_discount_text',
		    ),
		),
	) );

	/**
	* Packages Section
	*/

	Kirki::add_section( 'packages_settings' ,
		array(
		    'title'          => esc_html__( 'Packages' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    // 'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'packages_status',
		'label'       => esc_html__( 'Disable Packages Section', 'hotelica' ),
		'section'     => 'packages_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'packages_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'packages_settings',
		'default'  => esc_html__( 'Our Best Packages', 'hotelica' ),
		'partial_refresh' => array(
		    'packages_title' => array(
		        'selector'        => '.packages_title',
		        'render_callback' => 'hotelica_packages_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'packages_subtitle',
		'label'    => esc_html__( 'Subtitle', 'hotelica' ),
		'section'  => 'packages_settings',
		'default'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quaerat, dignissimos! Lorem ipsum dolor sit amet, consectetur.', 'hotelica' ),
		'partial_refresh' => array(
		    'packages_subtitle' => array(
		        'selector'        => '.packages_subtitle',
		        'render_callback' => 'hotelica_packages_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'select',
		'settings' => 'packages_category',
		'label'    => esc_html__( 'Choose Packages Category', 'hotelica' ),
		'section'  => 'packages_settings',
		'multiple'    => 1,
		'choices'     => hotelica_get_post_categories()
	) );

	/**
	* Testimonials Section
	*/

	Kirki::add_section( 'testimonials_settings' ,
		array(
		    'title'          => esc_html__( 'Testimonials' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    // 'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'testimonials_status',
		'label'       => esc_html__( 'Disable Testimonial Section', 'hotelica' ),
		'section'     => 'testimonials_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'testimonials_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'testimonials_settings',
		'default'  => esc_html__( 'What our guests says about us', 'hotelica' ),
		'partial_refresh' => array(
		    'testimonials_title' => array(
		        'selector'        => '.testimonials_title',
		        'render_callback' => 'hotelica_testimonials_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'testimonials_subtitle',
		'label'    => esc_html__( 'Subtitle', 'hotelica' ),
		'section'  => 'testimonials_settings',
		'default'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quaerat, dignissimos!', 'hotelica' ),
		'partial_refresh' => array(
		    'testimonials_subtitle' => array(
		        'selector'        => '.testimonials_subtitle',
		        'render_callback' => 'hotelica_testimonials_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'select',
		'settings'    => 'testimonials_category',
		'label'       => esc_html__( 'Select your testimonials category', 'hotelica' ),
		'section'     => 'testimonials_settings',
		'multiple'    => 1,
		'choices'     => Kirki_Helper::get_terms( array('taxonomy' => 'category') ),
	) );

	/**
	* Our Facitities Section
	*/

	Kirki::add_section( 'facilities_settings' ,
		array(
		    'title'          => esc_html__( 'Our Facilities' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    // 'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'facilities_status',
		'label'       => esc_html__( 'Disable Our Facilities Section', 'hotelica' ),
		'section'     => 'facilities_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'facilities_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'facilities_settings',
		'default'  => esc_html__( 'Our Hotel Facilities', 'hotelica' ),
		'partial_refresh' => array(
		    'facilities_title' => array(
		        'selector'        => '.facilities_title',
		        'render_callback' => 'hotelica_facilities_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'facilities_subtitle',
		'label'    => esc_html__( 'Subtitle', 'hotelica' ),
		'section'  => 'facilities_settings',
		'default'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quaerat, dignissimos! Lorem ipsum dolor sit amet, consectetur.', 'hotelica' ),
		'partial_refresh' => array(
		    'facilities_subtitle' => array(
		        'selector'        => '.facilities_subtitle',
		        'render_callback' => 'hotelica_facilities_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'select',
		'settings'    => 'facilities_category',
		'label'       => esc_html__( 'Select your facilities category', 'hotelica' ),
		'section'     => 'facilities_settings',
		'multiple'    => 1,
		'choices'     => Kirki_Helper::get_terms( array('taxonomy' => 'category') ),
	) );

	/**
	* Gallery Section
	*/

	Kirki::add_section( 'gallery_settings',
		array(
		    'title'          => esc_html__( 'Gallery' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    // 'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'gallery_status',
		'label'       => esc_html__( 'Disable Gallery Section', 'hotelica' ),
		'section'     => 'gallery_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'gallery_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'gallery_settings',
		'default'  => esc_html__( 'Gallery', 'hotelica' ),
		'partial_refresh' => array(
		    'gallery_title' => array(
		        'selector'        => '.gallery_title',
		        'render_callback' => 'hotelica_gallery_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'gallery_subtitle',
		'label'    => esc_html__( 'Subtitle', 'hotelica' ),
		'section'  => 'gallery_settings',
		'default'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quaerat, dignissimos! Lorem ipsum dolor sit amet, consectetur.', 'hotelica' ),
		'partial_refresh' => array(
		    'gallery_subtitle' => array(
		        'selector'        => '.gallery_subtitle',
		        'render_callback' => 'hotelica_gallery_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'        => 'repeater',
		'label'       => esc_html__( 'Gallery Images', 'hotelica' ),
		'section'     => 'gallery_settings',
		'row_label' => array(
			'type' => 'text',
			'value' => esc_html__( 'Image', 'hotelica' ),
		),
		'settings'    => 'gallery',
		'fields' => array(
			'image' => array(
				'type'        => 'image',
				'label'       => esc_html__( 'Image', 'hotelica' ),
			),
			'title' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Title', 'hotelica' ),
			),			
		),
		'choices' => apply_filters( 'hotelica_gallery_limit' , array( 'limit' => 6 ) ),
	) );

	/**
	* Blog Section
	*/

	Kirki::add_section( 'blog_settings',
		array(
		    'title'          => esc_html__( 'Blog' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'section'          => 'homepage_settings',
		    // 'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'checkbox',
		'settings'    => 'blog_status',
		'label'       => esc_html__( 'Disable Blog Section', 'hotelica' ),
		'section'     => 'blog_settings',
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'blog_title',
		'label'    => esc_html__( 'Title', 'hotelica' ),
		'section'  => 'blog_settings',
		'default'  => esc_html__( 'Blog', 'hotelica' ),
		'partial_refresh' => array(
		    'blog_title' => array(
		        'selector'        => '.blog_title',
		        'render_callback' => 'hotelica_blog_title',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'text',
		'settings' => 'blog_subtitle',
		'label'    => esc_html__( 'Subtitle', 'hotelica' ),
		'section'  => 'blog_settings',
		'default'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Quaerat, dignissimos! Lorem ipsum dolor sit amet, consectetur.', 'hotelica' ),
		'partial_refresh' => array(
		    'blog_subtitle' => array(
		        'selector'        => '.blog_subtitle',
		        'render_callback' => 'hotelica_blog_subtitle',
		    ),
		),
	) );

	Kirki::add_field( 'my_theme', array(
		'type'     => 'select',
		'settings' => 'blog_category',
		'label'    => esc_html__( 'Choose Blog Category', 'hotelica' ),
		'section'  => 'blog_settings',
		'multiple'    => 1,
		'choices'     => hotelica_get_post_categories(),
		'partial_refresh' => array(
		    'blog_category' => array(
		        'selector'        => '.blog_category',
		        'render_callback' => 'hotelica_get_blog_posts',
		    ),
		),
	) );

	/**
	* Footer Section
	*/

	Kirki::add_section( 'footer_settings',
		array(
		    'title'          => esc_html__( 'Footer' , 'hotelica' ),
		    'capability'     => 'edit_theme_options',
		    'panel'          => 'theme_options',
		) 
	);

	Kirki::add_field( 'my_theme', array(
		'type'        => 'repeater',
		'priority'    => 1,
		'label'       => esc_html__( 'Social Links', 'hotelica' ),
		'section'     => 'footer_settings',
		'row_label' => array(
			'type' => 'text',
			'value' => esc_html__( 'Social Link', 'hotelica' ),
		),
		'settings'    => 'footer_social_links',
		'fields' => array(
			'icon' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Fontawesome Icon', 'hotelica' ),
			),
			'link' => array(
				'type'        => 'text',
				'label'       => esc_html__( 'Link', 'hotelica' ),
			),			
		),
	) );	

	// if you are using nested panels or sections then a blank field is needed
    Kirki::add_field( 'my_theme', array(
        'type'     => 'notice',
        'section'  => 'homepage_settings',
    ));


}

add_action( 'customize_register', 'hotelica_custom_control_type' );
function hotelica_custom_control_type( $wp_customize ){

	class Hotelica_blank_content extends WP_Customize_Control {
		public $type = 'notice';
		public function render_content() { 
			echo '';
		}
	}

	// Register our custom control with Kirki
	add_filter( 'kirki/control_types', 'hotelica_kirki_notice_content' );

}

function hotelica_kirki_notice_content( $controls ){
	$controls['notice'] = 'Hotelica_blank_content';
	return $controls;
}